#
# spec file for package libtracefs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libtracefs
%define lname   libtracefs1
Version:        1.6.3
Release:        bp155.1.5
Summary:        Linux kernel trace file system library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://git.kernel.org/pub/scm/libs/libtrace/libtracefs.git/
Source:         https://git.kernel.org/pub/scm/libs/libtrace/libtracefs.git/snapshot/%name-%version.tar.gz
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(libtraceevent) >= 1.3

%description
This library provides C APIs to access the kernel trace file system.

%package -n %lname
Summary:        Linux kernel trace file system library
Group:          System/Libraries

%description -n %lname
This library provides C APIs to access the kernel trace file system.

%package devel
Summary:        Development files for libtracefs
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
This library provides C APIs to access the kernel trace file system.

This subpackage contains the header files.

%prep
%autosetup -p1

%build
%make_build V=1 prefix="%_prefix"

%install
%make_install V=1 prefix="%_prefix" \
	pkgconfig_dir=%{_libdir}/pkgconfig \
        %nil
# always the same issues
find "%buildroot/%_includedir" -type f -name "*.h" -exec chmod a-x {} +
rm -f "%buildroot/%_libdir"/*.a
if ldd -r "%buildroot/%_libdir/libtracefs.so" 2>&1 | grep -q undefined; then
	exit 1
fi

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libtracefs.so.1*
%license LICENSES/LGPL-2.1

%files devel
%_includedir/*
%_libdir/libtracefs.so
%_libdir/pkgconfig/*.pc

%changelog
* Fri Dec 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.3
  * Fix a regression of where tracefs_tracing_dir() did not mount
    the tracefs file system if it was not already mounted.
    Same for mounting debugfs with tracefs_debug_dir().
  * Have tracefs_tracing_dir() and tracefs_debug_dir() check if the
    cached directory still exists and is mounted.
* Fri Nov 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.1
  * Fix tracefs_iterate_raw_events() to handle NULL callback
* Wed Nov 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * No changelog provided by upstream
  * A set of new API functions
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.2
  * Build fixes only (parallel build, musl support)
* Tue Jun 21 2022 Jan Engelhardt <jengelh@inai.de>
- Force make -j1 during build because of object file corruption.
* Tue Jun  7 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (1.4.1)
  * Raw uprobe API: tracefs_uprobe_alloc(), tracefs_uretprobe_alloc
  * Return the debugfs mount point from tracefs_debug_dir()
  * sqlhst: Fix labels being ignored for synthetic event field
  * sqlhst: Allow same event to be both the start and end event
  * sqlhst: Use unique names for labels
  * sqlhst: Report errors when executing commands
* Tue Apr  5 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (1.3.1)
  * Optimized string list handling. It was always stated that some string
    lists must be freed with tracefs_list_free(), and now it is mandatory, as
    metadata is used to store the size, and normal freeing of the list will
    cause memory issues.
  * More consistency with errno values
  * sqlhist is now officially built
  * New methods for setting and reading affinity
    tracefs_instance_set_affinity_set()
    tracefs_instance_set_affinity_raw()
    tracefs_instance_set_affinity()
    tracefs_instance_get_affinity()
    tracefs_instance_get_affinity_raw()
    tracefs_instance_get_affinity_set()
  * New method to see the system tracers
    tracefs_instances()
  * New methods to read and clear the error log
    tracefs_error_last()
    tracefs_error_all()
    tracefs_error_clear()
  * New methods to modify the string lists
    tracefs_list_add()
    tracefs_list_size()
  * New method to stop the iterator over raw events
    tracefs_iterate_stop()
  * New methods to make it easier to access event files
    tracefs_event_get_file()
    tracefs_event_file_read()
    tracefs_event_file_write()
    tracefs_event_file_append()
    tracefs_event_file_clear()
    tracefs_event_file_exists()
  * New method to get the available filter functions
    tracefs_filter_functions()
  * New methods to enable or disable tracers
    tracefs_tracer_set()
    tracefs_tracer_clear()
  * New methods for streaming the trace_pipe file
    tracefs_trace_pipe_stream()
    tracefs_trace_pipe_print()
    tracefs_trace_pipe_stop()
  * New methods for creating, modifying and destroying dynamic events
    tracefs_dynevent_create()
    tracefs_dynevent_destroy()
    tracefs_dynevent_destroy_all()
    tracefs_dynevent_free()
    tracefs_dynevent_list_free()
    tracefs_dynevent_get_all()
    tracefs_dynevent_get()
    tracefs_dynevent_info()
    tracefs_dynevent_get_event()
  * New method to create an event probe (then use dynamic methods above)
    tracefs_eprobe_alloc()
  * New methods to create kprobes and kretprobes
    tracefs_kprobe_alloc()
    tracefs_kretprobe_alloc()
    tracefs_kprobe_raw()
    tracefs_kretprobe_raw()
  * New methods for creating, modifying and destroying histograms
    tracefs_hist_free()
    tracefs_hist_alloc()
    tracefs_hist_alloc_2d()
    tracefs_hist_alloc_nd()
    tracefs_hist_get_name()
    tracefs_hist_get_event()
    tracefs_hist_get_system()
    tracefs_hist_add_key()
    tracefs_hist_add_value()
    tracefs_hist_add_sort_key()
    tracefs_hist_set_sort_key()
    tracefs_hist_sort_key_direction()
    tracefs_hist_add_name()
    tracefs_hist_append_filter()
    tracefs_hist_echo_cmd()
    tracefs_hist_command()
    tracefs_hist_start()
    tracefs_hist_pause()
    tracefs_hist_continue()
    tracefs_hist_reset()
    tracefs_hist_destroy()
  * New methods for creating, modifying and destroying synthetic events
    tracefs_synth_get_name()
    tracefs_synth *tracefs_synth_alloc()
    tracefs_synth_add_match_field()
    tracefs_synth_add_compare_field()
    tracefs_synth_add_start_field()
    tracefs_synth_add_end_field()
    tracefs_synth_append_start_filter()
    tracefs_synth_append_end_filter()
    tracefs_synth_trace()
    tracefs_synth_snapshot()
    tracefs_synth_save()
    tracefs_synth_complete()
    tracefs_synth_get_start_hist()
    tracefs_synth_create()
    tracefs_synth_destroy()
    tracefs_synth_free()
    tracefs_synth_echo_cmd()
    tracefs_synth_raw_fmt()
    tracefs_synth_show_event()
    tracefs_synth_show_start_hist()
    tracefs_synth_show_end_hist()
    tracefs_synth_get_event()
  * New methods to modify event filters
    tracefs_filter_string_append()
    tracefs_filter_string_verify()
    tracefs_event_filter_apply()
    tracefs_event_filter_clear()
    tracefs_event_append_filter()
    tracefs_event_verify_filter()
  * New method to create a synthetic event via a SQL string
    tracefs_sql()
    The man page comes with its own program (sqlhist).
* Tue Feb 22 2022 olaf@aepfle.de
- Force correct pkgconfig_dir location to fix build
* Wed Jan 19 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (1.2.5)
  * No changelog provided again
* Fri May 14 2021 Dario Faggioli <dfaggioli@suse.com>
- Update to new upstream version (1.2.0)
  * No changelog was provided by upstream.
  * libtracefs: Add tracefs_event_enable/disable() API
* Mon May 10 2021 Dario Faggioli <dfaggioli@suse.com>
- update to new upstream version (1.1.2)
- drop patch 294319.patch (already present upstream)
* Tue Dec 22 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 1.0.0) for build.opensuse.org
- Add 294319.patch
